@@ -4,6 +4,7 @@ from cioc4d.sections.collapsible_section import CollapsibleSection
 from cioc4d.widgets.button_row import ButtonRow
 from cioc4d.widgets.path_widget import PathWidget
 from ciocore.gpath_list import GLOBBABLE_REGEX, PathList
+from ciocore.gpath import Path
 from cioc4d import const as k
 
 BG_COLOR = c4d.Vector(0.2, 0.2, 0.2)
@@ -153,8 +154,13 @@ class AssetsSection(CollapsibleSection):
         path_list.remove_missing()
 
         if k.C4D_VERSION < 22:
+            docfile = Path(os.path.join( 
+                document.GetDocumentPath(), document.GetDocumentName()
+                )).posix_path()
+
             asset_list = c4d.documents.GetAllAssets(document, False, '')
             path_list.add(*[asset["filename"]  for asset in asset_list if asset["exists"]  ] )
+            path_list.add(docfile)
         else:
             asset_list = []
             success = c4d.documents.GetAllAssetsNew(
@@ -172,21 +178,4 @@ class AssetsSection(CollapsibleSection):
         
 
 
- 
-
-# def _remove_missing_files(pathlist):
-#     # NOTE: This is temporary - SHOULD BE HANDLED IN GPathList class. We
-#     # remove any non-globbable paths that dont exist. We never want the
-#     # uploader to fail because of missing files. The reason is that the
-#     # uploader output is not user friendly and its hard to find the
-#     # culprits. Instead we alert the user about missing files and ask them
-#     # if they want to continue.
-#     result = PathList()
-#     for path in pathlist:
-#         pp = path.posix_path()
-#         if GLOBBABLE_REGEX.search(pp):
-#             result.add(path)
-#         else:
-#             if os.path.exists(pp):
-#                 result.add(path)
-#     return result
+  
\ No newline at end of file
